api.datastores.v1.store.test_helpers.store package — Argus-Toolbelt 1.0 documentation

# api.datastores.v1.store.test_helpers.store package

## Submodules

## api.datastores.v1.store.test_helpers.store.delete_data_store_entries module

`api.datastores.v1.store.test_helpers.store.delete_data_store_entries.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+, respond with HTTP 403

`api.datastores.v1.store.test_helpers.store.delete_data_store_entries.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+, respond with HTTP 404

`api.datastores.v1.store.test_helpers.store.delete_data_store_entries.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+, respond with HTTP 200

`api.datastores.v1.store.test_helpers.store.delete_data_store_entries.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+, respond with HTTP 401

## api.datastores.v1.store.test_helpers.store.get_entries_from_store module

`api.datastores.v1.store.test_helpers.store.get_entries_from_store.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+/search, respond with HTTP 403

`api.datastores.v1.store.test_helpers.store.get_entries_from_store.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+/search, respond with HTTP 404

`api.datastores.v1.store.test_helpers.store.get_entries_from_store.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+/search, respond with HTTP 200

`api.datastores.v1.store.test_helpers.store.get_entries_from_store.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+/search, respond with HTTP 401

## api.datastores.v1.store.test_helpers.store.get_entries_from_store_simplified module

`api.datastores.v1.store.test_helpers.store.get_entries_from_store_simplified.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+, respond with HTTP 403

`api.datastores.v1.store.test_helpers.store.get_entries_from_store_simplified.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+, respond with HTTP 404

`api.datastores.v1.store.test_helpers.store.get_entries_from_store_simplified.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+, respond with HTTP 200

`api.datastores.v1.store.test_helpers.store.get_entries_from_store_simplified.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+, respond with HTTP 401

## api.datastores.v1.store.test_helpers.store.get_single_entry module

`api.datastores.v1.store.test_helpers.store.get_single_entry.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+/w+, respond with HTTP 403

`api.datastores.v1.store.test_helpers.store.get_single_entry.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+/w+, respond with HTTP 404

`api.datastores.v1.store.test_helpers.store.get_single_entry.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+/w+, respond with HTTP 200

`api.datastores.v1.store.test_helpers.store.get_single_entry.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+/w+, respond with HTTP 401

## api.datastores.v1.store.test_helpers.store.put_data_store_entries module

`api.datastores.v1.store.test_helpers.store.put_data_store_entries.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+, respond with HTTP 403

`api.datastores.v1.store.test_helpers.store.put_data_store_entries.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+, respond with HTTP 404

`api.datastores.v1.store.test_helpers.store.put_data_store_entries.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+, respond with HTTP 200

`api.datastores.v1.store.test_helpers.store.put_data_store_entries.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+, respond with HTTP 401

## api.datastores.v1.store.test_helpers.store.put_single_data_store_entry module

`api.datastores.v1.store.test_helpers.store.put_single_data_store_entry.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+/w+/w+, respond with HTTP 403

`api.datastores.v1.store.test_helpers.store.put_single_data_store_entry.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+/w+/w+, respond with HTTP 404

`api.datastores.v1.store.test_helpers.store.put_single_data_store_entry.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+/w+/w+, respond with HTTP 200

`api.datastores.v1.store.test_helpers.store.put_single_data_store_entry.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/datastores/v1/store/w+/w+/w+, respond with HTTP 401

## Module contents